import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_1kpcm","start":"checkbox__start_1kpcm","center":"checkbox__center_1kpcm","addons":"checkbox__addons_1kpcm","block":"checkbox__block_1kpcm","box":"checkbox__box_1kpcm","checkedIcon":"checkbox__checkedIcon_1kpcm","s":"checkbox__s_1kpcm","disabled":"checkbox__disabled_1kpcm","checked":"checkbox__checked_1kpcm","indeterminate":"checkbox__indeterminate_1kpcm","label":"checkbox__label_1kpcm","hint":"checkbox__hint_1kpcm","focused":"checkbox__focused_1kpcm","content":"checkbox__content_1kpcm","indeterminateLine":"checkbox__indeterminateLine_1kpcm"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
